shopping_search()
Create a multi-marketplace product search tool.
Usage
shopping_search(
*,
provider="auto",
allowed_engines=None,
default_engine=None,
include_examples=True,
api_key=None,
client=None,
default_params=None,
timeout=None,
mode=SearchResultMode.COMPACT,
name="shopping_search"
)Parameters
provider: ProviderName | str = "auto"-
Agent SDK adapter name,
"auto", or"function"for a callable. allowed_engines: Iterable[ShoppingSearchEngine | str] | ShoppingSearchEngine | str | None = None-
Marketplaces exposed in the model-facing
engineenum. default_engine: ShoppingSearchEngine | str | None = None-
Marketplace used when the model omits
engine. include_examples: bool = True-
Add a short call example to the model-facing description.
api_key: str | None = None-
Runtime authentication, custom client, application filters, timeout, and compact or full response selection.
client: str | None = None-
Runtime authentication, custom client, application filters, timeout, and compact or full response selection.
default_params: str | None = None-
Runtime authentication, custom client, application filters, timeout, and compact or full response selection.
timeout: str | None = None-
Runtime authentication, custom client, application filters, timeout, and compact or full response selection.
mode: str | None = None-
Runtime authentication, custom client, application filters, timeout, and compact or full response selection.
name: str = "shopping_search"- Tool name presented to the model.
Returns
Any-
A provider-native tool whose input fields are
queryandengine.